@@ -102,7 +102,7 @@ from gwaslab.viz.viz_plot_mqqplot import mqqplot
 from gwaslab.viz.viz_plot_trumpetplot import plottrumpet
 from gwaslab.viz.viz_plot_compare_af import plotdaf
 from gwaslab.viz.viz_plot_credible_sets import _plot_cs
-
+from gwaslab.viz.viz_plot_associations import _plot_associations
 from gwaslab.io.io_read_pipcs import _read_pipcs
 from gwaslab.io.io_load_ld import tofinemapping_using_ld
 from gwaslab.io.io_preformat_input import preformat
@@ -112,6 +112,7 @@ from gwaslab.io.io_to_pickle import _reload
 
 #20220309
 class Sumstats():
+    
     def __init__(self,
              sumstats=None,
              fmt=None,
@@ -274,6 +275,10 @@ class Sumstats():
         self.id = id(self)
         self.tmp_path = _path(pid=self.id, log = self.log, verbose=verbose)
 
+    def __getitem__(self, index):
+        return self.data[index]
+    def __len__(self):
+        return len(self.data)
 #### healper #################################################################################
     def update_meta(self, **kwargs):
         self.meta = _update_meta(self.meta, self.data,log = self.log, **kwargs)
@@ -695,7 +700,8 @@ class Sumstats():
         return fig, outliers
     
     def infer_ancestry(self, **kwargs):
-        self.meta["gwaslab"]["inferred_ancestry"] = _infer_ancestry(self.data, **kwargs)
+        self.meta["gwaslab"]["inferred_ancestry"] = _infer_ancestry(self.data, log=self.log,
+                                                                    **kwargs)
 
     def plot_gwheatmap(self, **kwargs):
         fig = _gwheatmap(self.data, **kwargs)
@@ -811,6 +817,9 @@ class Sumstats():
         self.associations = associations_full
         
         return associations_summary
+    def plot_associations(self,**kwargs):
+
+        _plot_associations(self.associations, **kwargs)
 
     def check_cis(self, gls=False, **kwargs):
         if "SNPID" in self.data.columns:
